@@ -1,7 +1,7 @@
 package Perinci::CmdLine::Inline;
 
-our $DATE = '2016-02-26'; # DATE
-our $VERSION = '0.36'; # VERSION
+our $DATE = '2016-03-16'; # DATE
+our $VERSION = '0.37'; # VERSION
 
 use 5.010001;
 use strict;
@@ -725,13 +725,13 @@ _
             ("# code_after_shebang\n", $args{code_after_shebang}, "\n") x !!$args{code_after_shebang},
 
             "# PERICMD_INLINE_SCRIPT: ", do {
-                require JSON;
+                require JSON::MaybeXS;
                 my %tmp = %args;
                 # don't show the potentially long/undumpable argument values
                 for (grep {/^code_/} keys %tmp) {
                     $tmp{$_} = "...";
                 }
-                JSON::encode_json(\%tmp);
+                JSON::MaybeXS::encode_json(\%tmp);
             }, "\n\n",
 
             "# This script is generated by ", __PACKAGE__,
@@ -830,7 +830,7 @@ Perinci::CmdLine::Inline - Generate inline Perinci::CmdLine CLI script
 
 =head1 VERSION
 
-This document describes version 0.36 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-02-26.
+This document describes version 0.37 of Perinci::CmdLine::Inline (from Perl distribution Perinci-CmdLine-Inline), released on 2016-03-16.
 
 =head1 SYNOPSIS
 
